@@ -5,13 +5,13 @@
 */
 
 #include "udisksmanager.h"
-#include "udisksdevicebackend.h"
 #include "udisks_debug.h"
+#include "udisksdevicebackend.h"
 
 #include <QDBusConnection>
-#include <QDBusObjectPath>
-#include <QDBusMetaType>
 #include <QDBusConnectionInterface>
+#include <QDBusMetaType>
+#include <QDBusObjectPath>
 #include <QDomDocument>
 
 #include "../shared/rootdevice.h"
@@ -20,21 +20,20 @@ using namespace Solid::Backends::UDisks2;
 using namespace Solid::Backends::Shared;
 
 Manager::Manager(QObject *parent)
-    : Solid::Ifaces::DeviceManager(parent),
-      m_manager(UD2_DBUS_SERVICE,
-                UD2_DBUS_PATH,
-                QDBusConnection::systemBus())
+    : Solid::Ifaces::DeviceManager(parent)
+    , m_manager(UD2_DBUS_SERVICE, UD2_DBUS_PATH, QDBusConnection::systemBus())
 {
-    m_supportedInterfaces
-            << Solid::DeviceInterface::GenericInterface
-            << Solid::DeviceInterface::Block
-            << Solid::DeviceInterface::StorageAccess
-            << Solid::DeviceInterface::StorageDrive
-            << Solid::DeviceInterface::OpticalDrive
-            << Solid::DeviceInterface::OpticalDisc
-            << Solid::DeviceInterface::StorageVolume;
+    m_supportedInterfaces = {
+        Solid::DeviceInterface::GenericInterface,
+        Solid::DeviceInterface::Block,
+        Solid::DeviceInterface::StorageAccess,
+        Solid::DeviceInterface::StorageDrive,
+        Solid::DeviceInterface::OpticalDrive,
+        Solid::DeviceInterface::OpticalDisc,
+        Solid::DeviceInterface::StorageVolume,
+    };
 
-    qDBusRegisterMetaType<QList<QDBusObjectPath> >();
+    qDBusRegisterMetaType<QList<QDBusObjectPath>>();
     qDBusRegisterMetaType<QVariantMap>();
     qDBusRegisterMetaType<VariantMapMap>();
     qDBusRegisterMetaType<DBUSManagerStruct>();
@@ -42,10 +41,10 @@ Manager::Manager(QObject *parent)
     bool serviceFound = m_manager.isValid();
     if (!serviceFound) {
         // find out whether it will be activated automatically
-        QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.DBus",
-                               "/org/freedesktop/DBus",
-                               "org.freedesktop.DBus",
-                               "ListActivatableNames");
+        QDBusMessage message = QDBusMessage::createMethodCall("org.freedesktop.DBus", //
+                                                              "/org/freedesktop/DBus",
+                                                              "org.freedesktop.DBus",
+                                                              "ListActivatableNames");
 
         QDBusReply<QStringList> reply = QDBusConnection::systemBus().call(message);
         if (reply.isValid() && reply.value().contains(UD2_DBUS_SERVICE)) {
@@ -55,10 +54,8 @@ Manager::Manager(QObject *parent)
     }
 
     if (serviceFound) {
-        connect(&m_manager, SIGNAL(InterfacesAdded(QDBusObjectPath,VariantMapMap)),
-                this, SLOT(slotInterfacesAdded(QDBusObjectPath,VariantMapMap)));
-        connect(&m_manager, SIGNAL(InterfacesRemoved(QDBusObjectPath,QStringList)),
-                this, SLOT(slotInterfacesRemoved(QDBusObjectPath,QStringList)));
+        connect(&m_manager, SIGNAL(InterfacesAdded(QDBusObjectPath, VariantMapMap)), this, SLOT(slotInterfacesAdded(QDBusObjectPath, VariantMapMap)));
+        connect(&m_manager, SIGNAL(InterfacesRemoved(QDBusObjectPath, QStringList)), this, SLOT(slotInterfacesRemoved(QDBusObjectPath, QStringList)));
     }
 }
 
@@ -119,16 +116,15 @@ QStringList Manager::allDevices()
 {
     m_deviceCache.clear();
 
-    introspect("/org/freedesktop/UDisks2/block_devices", true /*checkOptical*/);
-    introspect("/org/freedesktop/UDisks2/drives");
+    introspect(UD2_DBUS_PATH_BLOCKDEVICES, true /*checkOptical*/);
+    introspect(UD2_DBUS_PATH_DRIVES);
 
     return m_deviceCache;
 }
 
 void Manager::introspect(const QString &path, bool checkOptical)
 {
-    QDBusMessage call = QDBusMessage::createMethodCall(UD2_DBUS_SERVICE, path,
-                        DBUS_INTERFACE_INTROSPECT, "Introspect");
+    QDBusMessage call = QDBusMessage::createMethodCall(UD2_DBUS_SERVICE, path, DBUS_INTERFACE_INTROSPECT, "Introspect");
     QDBusPendingReply<QString> reply = QDBusConnection::systemBus().call(call);
 
     if (reply.isValid()) {
@@ -138,12 +134,18 @@ void Manager::introspect(const QString &path, bool checkOptical)
         for (int i = 0; i < nodeList.count(); i++) {
             QDomElement nodeElem = nodeList.item(i).toElement();
             if (!nodeElem.isNull() && nodeElem.hasAttribute("name")) {
-                const QString udi = path + "/" + nodeElem.attribute("name");
+                const QString name = nodeElem.attribute("name");
+                const QString udi = path + "/" + name;
 
-                if (checkOptical) {
+                // Optimization, a loop device cannot really have a physical drive associated with it
+                if (checkOptical && !name.startsWith(QLatin1String("loop"))) {
                     Device device(udi);
                     if (device.mightBeOpticalDisc()) {
-                        QDBusConnection::systemBus().connect(UD2_DBUS_SERVICE, udi, DBUS_INTERFACE_PROPS, "PropertiesChanged", this,
+                        QDBusConnection::systemBus().connect(UD2_DBUS_SERVICE, //
+                                                             udi,
+                                                             DBUS_INTERFACE_PROPS,
+                                                             "PropertiesChanged",
+                                                             this,
                                                              SLOT(slotMediaChanged(QDBusMessage)));
                         if (!device.isOpticalDisc()) { // skip empty CD disc
                             continue;
@@ -159,7 +161,7 @@ void Manager::introspect(const QString &path, bool checkOptical)
     }
 }
 
-QSet< Solid::DeviceInterface::Type > Manager::supportedInterfaces() const
+QSet<Solid::DeviceInterface::Type> Manager::supportedInterfaces() const
 {
     return m_supportedInterfaces;
 }
@@ -187,8 +189,12 @@ void Manager::slotInterfacesAdded(const QDBusObjectPath &object_path, const Vari
     if (interfaces_and_properties.contains("org.freedesktop.UDisks2.Block")) {
         Device device(udi);
         if (device.mightBeOpticalDisc()) {
-            QDBusConnection::systemBus().connect(UD2_DBUS_SERVICE, udi, DBUS_INTERFACE_PROPS, "PropertiesChanged", this,
-                SLOT(slotMediaChanged(QDBusMessage)));
+            QDBusConnection::systemBus().connect(UD2_DBUS_SERVICE, //
+                                                 udi,
+                                                 DBUS_INTERFACE_PROPS,
+                                                 "PropertiesChanged",
+                                                 this,
+                                                 SLOT(slotMediaChanged(QDBusMessage)));
         }
     }
 
@@ -197,11 +203,11 @@ void Manager::slotInterfacesAdded(const QDBusObjectPath &object_path, const Vari
     // new device, we don't know it yet
     if (!m_deviceCache.contains(udi)) {
         m_deviceCache.append(udi);
-        emit deviceAdded(udi);
+        Q_EMIT deviceAdded(udi);
     }
     // re-emit in case of 2-stage devices like N9 or some Android phones
     else if (m_deviceCache.contains(udi) && interfaces_and_properties.keys().contains(UD2_DBUS_INTERFACE_FILESYSTEM)) {
-        emit deviceAdded(udi);
+        Q_EMIT deviceAdded(udi);
     }
 }
 
@@ -231,7 +237,7 @@ void Manager::slotInterfacesRemoved(const QDBusObjectPath &object_path, const QS
 
     if (leftInterfaces.isEmpty()) {
         // remove the device if the last interface is removed
-        emit deviceRemoved(udi);
+        Q_EMIT deviceRemoved(udi);
         m_deviceCache.removeAll(udi);
         DeviceBackend::destroyBackend(udi);
     } else {
@@ -240,8 +246,8 @@ void Manager::slotInterfacesRemoved(const QDBusObjectPath &object_path, const QS
          * matches a Predicate. We have to do a remove-and-readd cycle
          * as there is no dedicated signal for Predicate reevaluation.
          */
-        emit deviceRemoved(udi);
-        emit deviceAdded(udi);
+        Q_EMIT deviceRemoved(udi);
+        Q_EMIT deviceAdded(udi);
     }
 }
 
@@ -260,11 +266,11 @@ void Manager::slotMediaChanged(const QDBusMessage &msg)
 
     if (!m_deviceCache.contains(udi) && size > 0) { // we don't know the optdisc, got inserted
         m_deviceCache.append(udi);
-        emit deviceAdded(udi);
+        Q_EMIT deviceAdded(udi);
     }
 
-    if (m_deviceCache.contains(udi) && size == 0) {  // we know the optdisc, got removed
-        emit deviceRemoved(udi);
+    if (m_deviceCache.contains(udi) && size == 0) { // we know the optdisc, got removed
+        Q_EMIT deviceRemoved(udi);
         m_deviceCache.removeAll(udi);
         DeviceBackend::destroyBackend(udi);
     }
@@ -286,7 +292,7 @@ void Manager::updateBackend(const QString &udi)
         return;
     }
 
-    //This doesn't emit "changed" signals. Signals are emitted later by DeviceBackend's slots
+    // This doesn't emit "changed" signals. Signals are emitted later by DeviceBackend's slots
     backend->allProperties();
 
     QVariant driveProp = backend->prop("Drive");
